@@ -8,7 +8,7 @@ $PERL_VERSION =~ s|^v||;
 
 use OpenGL qw/ :all /;
 
-eval 'use OpenGL::Image';
+eval 'use OpenGL::Image 1.03';  # Need to use OpenGL::Image 1.03 or higher!
 my $hasImage = !$@;
 my $hasIM_635 = $hasImage && OpenGL::Image::HasEngine('Magick','6.3.5');
 
@@ -66,7 +66,7 @@ use constant DO_TESTS => 0;
 
 # Run in Game Mode
 my $gameMode;
-if (lc($ARGV[0]) eq 'gamemode')
+if ($#ARGV and lc($ARGV[0]) eq 'gamemode')
 {
   $gameMode = $ARGV[1] || '';
 }
@@ -1219,7 +1219,8 @@ sub cbKeyPressed
   }
   elsif ($c eq 'K')
   {
-    glutLeaveMainLoop();
+    # ignore keypress if not FreeGLUT
+    glutLeaveMainLoop() if OpenGL::_have_freeglut();
   }
   elsif ($c eq 'L')
   {
@@ -1484,6 +1485,25 @@ glutInit();
 # To see OpenGL drawing, take out the GLUT_DOUBLE request.
 glutInitDisplayMode(GLUT_RGBA | GLUT_DOUBLE | GLUT_DEPTH | GLUT_ALPHA);
 
+if ($^O ne 'MSWin32') { # skip these MODE checks on win32, they don't work
+
+   if (not glutGet(GLUT_DISPLAY_MODE_POSSIBLE))
+   {
+      warn "glutInitDisplayMode(GLUT_RGBA | GLUT_DOUBLE | GLUT_DEPTH | GLUT_ALPHA) not possible";
+      warn "...trying without GLUT_ALPHA";
+      # try without GLUT_ALPHA
+      glutInitDisplayMode(GLUT_RGBA | GLUT_DOUBLE | GLUT_DEPTH);
+      if (not glutGet(GLUT_DISPLAY_MODE_POSSIBLE))
+      {
+         warn "glutInitDisplayMode(GLUT_RGBA | GLUT_DOUBLE | GLUT_DEPTH) not possible, exiting quietly";
+         exit 0;
+      }
+   }
+
+}
+
+#glutInitDisplayString("rgb alpha>=0 double depth");
+
 # Open Window
 if (defined($gameMode) && glutGameModeString($gameMode))
 {
@@ -1562,7 +1582,7 @@ glutMouseFunc(\&cbMouseClick);
 #glutPassiveMotionFunc(\&cbMouseTrack);
 
 # Handle window close events.
-glutCloseFunc(\&cbClose);
+glutCloseFunc(\&cbClose) if OpenGL::_have_freeglut();
 
 # OK, OpenGL's ready to go.  Let's call our own init function.
 ourInit($Window_Width, $Window_Height);
@@ -1582,7 +1602,10 @@ Press 'c' to capture/save a RGBA targa file.
 
 # Pass off control to OpenGL.
 # Above functions are called as appropriate.
-glutSetOption(GLUT_ACTION_ON_WINDOW_CLOSE,GLUT_ACTION_GLUTMAINLOOP_RETURNS);
+if (OpenGL::_have_freeglut()) {
+   glutSetOption(GLUT_ACTION_ON_WINDOW_CLOSE,GLUT_ACTION_GLUTMAINLOOP_RETURNS)
+}
+
 glutMainLoop();
 
 print "FreeGLUT returned from MainLoop\n";
